@@ -21,7 +21,7 @@ from xmlrpc import client as xmlrpc
 
 import httpx
 
-__ALL__ = ["ServerProxy", "Fault", "ProtocolError"]
+__ALL__ = ["ServerProxy", "Fault", "ProtocolError", "MultiCall"]
 
 RPCResult = Any
 RPCParameters = Any
@@ -76,7 +76,7 @@ class AioTransport(xmlrpc.Transport):
         self,
         host: str,
         handler: str,
-        request_body: dict[str, Any],
+        request_body: bytes,
         verbose: bool = False,
     ) -> RPCResult:
         """
@@ -88,7 +88,7 @@ class AioTransport(xmlrpc.Transport):
         try:
             response = await self._session.post(
                 url,
-                data=request_body,
+                content=request_body,
                 auth=self.auth,
                 timeout=self.timeout,
             )
@@ -208,3 +208,16 @@ class ServerProxy(xmlrpc.ServerProxy):
 
     def __getattr__(self, name: str) -> _Method:  # type: ignore
         return _Method(self.__request, name)
+
+
+class MultiCall(xmlrpc.MultiCall):
+    __server: ServerProxy
+
+    async def __call__(self) -> xmlrpc.MultiCallIterator:  # type: ignore
+        marshalled_list = []
+        for name, args in self.__call_list:
+            marshalled_list.append({"methodName": name, "params": args})
+
+        return xmlrpc.MultiCallIterator(
+            await self.__server.system.multicall(marshalled_list)
+        )
